==> extendable-immutable-1.0.0.tgz: package/es/util/createExtendable.js <==
import _Object$create from 'babel-runtime/core-js/object/create';
import _Symbol from 'babel-runtime/core-js/symbol';
import invariant from 'invariant';

var emptySymbol = _Symbol('empty');

export default function createExtendable(base, copy, empty) {
  var additionalWrapped = arguments.length <= 3 || arguments[3] === undefined ? [] : arguments[3];

  invariant(typeof copy === 'function', name + ': `copy` is expected to be a function.');
  invariant(typeof empty === 'function', name + ': `empty` is expected to be a function.');

  var name = base.prototype.constructor.name;
  var proto = _Object$create(base.prototype);

  // A method for wrapping an immutable object, with reference equality for empty objects
  proto.__wrapImmutable = function __wrapImmutable(val) {
    var constructor = this.constructor;
    var prototype = constructor.prototype;


    if (!val.size && !val.__ownerID) {
      if (!constructor[emptySymbol]) {
        constructor[emptySymbol] = empty(_Object$create(prototype));
      }

      return constructor[emptySymbol];
    }

    return copy(_Object$create(prototype), val);
  };

  // Methods which will yield a Map and have to be wrapped before returning a result
  for (var key in base.prototype) {
    if (!key.startsWith('__') && base.prototype.hasOwnProperty(key)) {
      (function () {
        var _originalMethod = base.prototype[key];

        if (typeof _originalMethod === 'function') {
          proto[key] = function wrappedMethod() {
            for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
              args[_key] = arguments[_key];
            }

            var res = _originalMethod.apply(this, args);
            if (res instanceof base && !(res instanceof proto.constructor)) {
              return this.__wrapImmutable(res);
            }

            return res;
          };
        }
      })();
    }
  }

  proto.__ensureOwner = function __ensureOwner(ownerID) {
    if (ownerID === this.__ownerID) {
      return this;
    } else if (!ownerID) {
      this.__ownerID = undefined;
      this.__altered = false;
      return this;
    }

    var res = copy(_Object$create(proto), this);
    res.__ownerID = ownerID;
    return res;
  };

  return proto;
}

==> extendable-immutable-1.0.1.tgz: package/es/util/createExtendable.js <==
import _Object$create from 'babel-runtime/core-js/object/create';
import _Symbol from 'babel-runtime/core-js/symbol';
import invariant from 'invariant';

var emptySymbol = _Symbol('empty');

export default function createExtendable(base, copy, empty) {
  var additionalWrapped = arguments.length <= 3 || arguments[3] === undefined ? [] : arguments[3];

  invariant(typeof copy === 'function', name + ': `copy` is expected to be a function.');
  invariant(typeof empty === 'function', name + ': `empty` is expected to be a function.');

  var name = base.prototype.constructor.name;
  var proto = _Object$create(base.prototype);

  // A method for wrapping an immutable object, with reference equality for empty objects
  proto.__wrapImmutable = function __wrapImmutable(val) {
    var forceCreation = arguments.length <= 1 || arguments[1] === undefined ? false : arguments[1];
    var constructor = this.constructor;
    var prototype = constructor.prototype;


    if (!forceCreation && !val.size && !val.__ownerID) {
      if (!constructor[emptySymbol]) {
        constructor[emptySymbol] = empty(_Object$create(prototype));
      }

      return constructor[emptySymbol];
    }

    return copy(_Object$create(prototype), val);
  };

  // Methods which will yield a Map and have to be wrapped before returning a result
  for (var key in base.prototype) {
    if (!key.startsWith('__') && key !== 'to' + name && base.prototype.hasOwnProperty(key)) {
      (function () {
        var _originalMethod = base.prototype[key];

        if (typeof _originalMethod === 'function') {
          proto[key] = function wrappedMethod() {
            for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
              args[_key] = arguments[_key];
            }

            var res = _originalMethod.apply(this, args);
            if (res instanceof base && !(res instanceof proto.constructor)) {
              return this.__wrapImmutable(res);
            }

            return res;
          };
        }
      })();
    }
  }

  proto.__ensureOwner = function __ensureOwner(ownerID) {
    if (ownerID === this.__ownerID) {
      return this;
    } else if (!ownerID) {
      this.__ownerID = undefined;
      this.__altered = false;
      return this;
    }

    var res = this.__wrapImmutable(this, true);
    res.__ownerID = ownerID;
    return res;
  };

  return proto;
}
